#ifndef _RIGHTS_H_
#define _RIGHTS_H_

namespace
{
	const char* RIGHT_ALL = "all";
	const char* RIGHT_SETTINGS="settings";
	const char* RIGHT_BROWSE_BACKUPS = "browse_backups";
	const char* RIGHT_ALERT_SCRIPTS = "alert_scripts";
	const char* RIGHT_REPORT_SCRIPT = "report_script";
}

#endif //_RIGHTS_H_